@@ -29,6 +29,12 @@ def batch_map(glob_pattern, command, replace_from, replace_to, j=4, dry_run=Fals
     return 0
 
 
+def _glo(glob_pattern):
+    glob_pattern = str(glob_pattern)
+    files = glob.glob(glob_pattern, recursive=True)
+    print(len(files))
+
+
 def rename():
     print("yata './**/*' --command 'mv {i} {o}' --replace_from .aac --replace_to .wav --j 4 --dry_run True")  
 
@@ -40,6 +46,9 @@ def main():
     fire.Fire(batch_map)
     return 0
 
+def glo():
+    fire.Fire(_glo)
+    return 0
 
 def guide():
     fire.Fire()
